@@ -532,11 +532,7 @@ impl<I: Tokens> Parser<I> {
         if !self.input.syntax().typescript() {
             return None;
         }
-        #[cfg(feature = "debug")]
-        let _tracing = {
-            let cur = format!("{:?}", self.input.cur());
-            tracing::span!(tracing::Level::ERROR, "try_parse_ts", cur = &*cur).entered()
-        };
+        let _tracing = debug_tracing!(self, "try_parse_ts");
 
         trace_cur!(self, try_parse_ts);
 
@@ -2636,6 +2632,8 @@ impl<I: Tokens> Parser<I> {
     {
         debug_assert!(self.input.syntax().typescript());
 
+        trace_cur!(self, ts_in_no_context__before);
+
         let cloned = self.input.token_context().clone();
 
         #[cfg(debug_assertions)]
@@ -2647,6 +2645,8 @@ impl<I: Tokens> Parser<I> {
         let res = op(self);
         self.input.set_token_context(cloned);
 
+        trace_cur!(self, ts_in_no_context__after);
+
         res
     }
 }
